use super::Arguments;
use super::raw_audio::{I16Samples, Settings};
use std::io::Write;
use symphonia::core::audio::Layout;
use tool_helper::Error;

const HIGH_FREQUENCY:u32 = 37_800;
const  LOW_FREQUENCY:u32 = 18_900;

pub fn audio_conversion_settings(arguments: &Arguments) -> Settings {
    let frequency = match arguments.frequency {
        super::Frequency::High => HIGH_FREQUENCY,
        super::Frequency::Low  => LOW_FREQUENCY,
    };
    let layout    = match arguments.channels {
        super::Channels::Stereo => Layout::Stereo,
        super::Channels::Mono   => Layout::Mono,
    };

    Settings::new(frequency, layout)
}

pub fn convert(input: I16Samples, _output: &mut dyn Write, arguments: &Arguments) -> Result<(), Error> {
    let (samples_per_block, sample_count) = init_values(&input, arguments);

    for (iteration, sampled_id) in (0..sample_count).step_by(samples_per_block).enumerate() {
        print!("\rIteration: {}; Sample: {}", iteration, sampled_id);
    }
    println!();
    Err(Error::not_implemented("XA conversion"))
}

fn init_values(input: &I16Samples, arguments: &Arguments) -> (usize, u32) {
    let samples_per_block = match arguments.sample_depth {
        super::SampleDepth::Normal => 224,
        super::SampleDepth::High   => 112,
    };

    let sample_count = match arguments.channels {
        super::Channels::Stereo => input.len() / 2,
        super::Channels::Mono   => input.len(),
    };

    (samples_per_block as usize, sample_count as u32)
}